@@ -1,18 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
+ * SPDX-FileCopyrightText: 2021 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2021 G. DE BURE support@mankowski.fr
+ * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
  * The grantlee's filter to get items of a document table.
@@ -62,10 +51,14 @@ QVariant SKGDocumentTableFilter::doFilter(const QVariant& input, const QVariant&
         SKGObjectBase::SKGListSKGObjectBase objects;
         QString table = Grantlee::getSafeString(argument);
         QString wc;
-        int pos = table.lastIndexOf(QStringLiteral(","));
+        int pos = table.indexOf(QStringLiteral(","));
         if (pos != -1) {
-            wc = table.right(table.count() - pos - 1);
-            table = table.left(pos);
+            if(table.at(table.count()-1)==QStringLiteral(",")) {
+                table = table.left(table.count()-1);
+            } else {
+                wc = table.right(table.count() - pos - 1);
+                table = table.left(pos);
+           }
         }
         if (report != nullptr) {
             table = fixSQL(report, table);
