@@ -1,18 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
+ * SPDX-FileCopyrightText: 2021 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2021 G. DE BURE support@mankowski.fr
+ * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
  * This file is Skrooge plugin for BACKEND import / export.
@@ -29,6 +18,7 @@
 #include <qprocess.h>
 #include <qstandardpaths.h>
 #include <qtconcurrentmap.h>
+#include <qregularexpression.h>
 
 #include <kaboutdata.h>
 #include <klocalizedstring.h>
@@ -172,9 +162,9 @@ SKGError SKGImportPluginBackend::importFile()
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", csvfile));
         } else {
-            QRegExp reggetaccounts(getParameter(QStringLiteral("X-SKROOGE-getaccountid")));
-            QRegExp reggetaccountbalance(getParameter(QStringLiteral("X-SKROOGE-getaccountbalance")));
-            QRegExp reggetaccountname(getParameter(QStringLiteral("X-SKROOGE-getaccountname")));
+            QRegularExpression reggetaccounts(getParameter(QStringLiteral("X-SKROOGE-getaccountid")));
+            QRegularExpression reggetaccountbalance(getParameter(QStringLiteral("X-SKROOGE-getaccountbalance")));
+            QRegularExpression reggetaccountname(getParameter(QStringLiteral("X-SKROOGE-getaccountname")));
 
             QTextStream stream(&file);
             stream.readLine();  // To avoid header
@@ -185,9 +175,9 @@ SKGError SKGImportPluginBackend::importFile()
                 SKGTRACEL(10) << "Read line: " << line << SKGENDL;
 
                 // Get account id
-                int pos = reggetaccounts.indexIn(line);
-                if (pos > -1) {
-                    QString accountid = reggetaccounts.cap(1);
+                auto match = reggetaccounts.match(line);
+                if (match.hasMatch()) {
+                    QString accountid = match.captured(1);
                     QString uniqueid = SKGServices::splitCSVLine(accountid, QLatin1Char('@')).at(0);
 
                     if (!backendAccounts.contains(accountid) && !backendAccountsUniqueId.contains(uniqueid)) {
@@ -195,17 +185,17 @@ SKGError SKGImportPluginBackend::importFile()
                         backendAccountsUniqueId.push_back(uniqueid);
 
                         // Get account balance
-                        pos = reggetaccountbalance.indexIn(line);
-                        if (pos > -1) {
-                            backendAccountsBalance[accountid] = reggetaccountbalance.cap(1);
+                        match = reggetaccountbalance.match(line);
+                        if (match.hasMatch()) {
+                            backendAccountsBalance[accountid] = match.captured(1);
                         } else {
                             backendAccountsBalance[accountid] = '0';
                         }
 
                         // Get account name
-                        pos = reggetaccountname.indexIn(line);
-                        if (pos > -1) {
-                            backendAccountsName[accountid] = reggetaccountname.cap(1);
+                        match = reggetaccountname.match(line);
+                        if (match.hasMatch()) {
+                            backendAccountsName[accountid] = match.captured(1);
                         } else {
                             backendAccountsName[accountid] = QLatin1String("");
                         }
