@@ -1,18 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
+ * SPDX-FileCopyrightText: 2021 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2021 G. DE BURE support@mankowski.fr
+ * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
  * This file is Skrooge plugin for CSV import / export.
@@ -28,6 +17,7 @@
 #include <qcryptographichash.h>
 #include <qfileinfo.h>
 #include <qsavefile.h>
+#include <qregularexpression.h>
 
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
@@ -126,7 +116,7 @@ QStringList SKGImportPluginCsv::getCSVMappingFromLine(const QString& iLine)
                 if (key != QStringLiteral("debit") &&
                     key != QStringLiteral("property") &&
                     !csvMapperIterator.value().isEmpty() &&
-                    QRegExp(csvMapperIterator.value(), Qt::CaseInsensitive).indexIn(att) != -1 &&
+                    QRegularExpression(csvMapperIterator.value(), QRegularExpression::CaseInsensitiveOption).match(att).hasMatch() &&
                     (!output.contains(key) || key == QStringLiteral("comment") || key == QStringLiteral("category") || key == QStringLiteral("amount"))) {
                     output.push_back(key);
                     found = true;
@@ -137,7 +127,7 @@ QStringList SKGImportPluginCsv::getCSVMappingFromLine(const QString& iLine)
         // Search if this csv column must be added as a property
         if (!found &&
             !m_importParameters.value(QStringLiteral("mapping_property")).isEmpty() &&
-            QRegExp(m_importParameters.value(QStringLiteral("mapping_property")), Qt::CaseInsensitive).indexIn(att) != -1 &&
+            QRegularExpression(m_importParameters.value(QStringLiteral("mapping_property")), QRegularExpression::CaseInsensitiveOption).match(att).hasMatch() &&
             !output.contains(att)) {
             output.push_back(att);
             found = true;
@@ -586,7 +576,7 @@ SKGError SKGImportPluginCsv::importFile()
                                 } else if (col == QStringLiteral("quantity")) {
                                     err = currentSubOperation.setQuantity(SKGServices::stringToDouble(val));
                                 } else if (col == QStringLiteral("sign")) {
-                                    if (QRegExp(m_importParameters.value(QStringLiteral("mapping_debit")), Qt::CaseInsensitive).indexIn(val) != -1) {
+                                    if (QRegularExpression(m_importParameters.value(QStringLiteral("mapping_debit")), QRegularExpression::CaseInsensitiveOption).match(val).hasMatch()) {
                                         sign = -1;
                                         double cval = currentSubOperation.getQuantity();
                                         if (cval > 0) {
