@@ -1,18 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
+ * SPDX-FileCopyrightText: 2021 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2021 G. DE BURE support@mankowski.fr
+ * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
  * This file is Skrooge plugin for import and export operation.
@@ -30,10 +19,12 @@
 #include <kpluginfactory.h>
 #include <kservice.h>
 #include <kservicetypetrader.h>
+#include <kmessagebox.h>
 
 #include <qaction.h>
 #include <qdiriterator.h>
 #include <qdom.h>
+#include <qregularexpression.h>
 #include <qstandardpaths.h>
 #include <qsysinfo.h>
 #include <qtextcodec.h>
@@ -218,8 +209,14 @@ QStringList SKGImportExportPlugin::processArguments(const QStringList& iArgument
         QString extension = QFileInfo(filename).suffix().toUpper();
         QString extensionDocument = m_currentBankDocument->getFileExtension().toUpper();
         if (QFile(filename).exists() && extension != extensionDocument) {
-            Q_EMIT importFileName(filename);
-            output.pop_back();
+            int rc = KMessageBox::questionYesNo(SKGMainPanel::getMainPanel(),i18nc("Question",  "Do you really want to import %1 into the current document ?", filename),
+                                                i18nc("Question",  "Import confirmation"),
+                                                KStandardGuiItem::yes(), KStandardGuiItem::no(),
+                                                QStringLiteral("importconfirmation"));
+            if (rc == KMessageBox::Yes) {
+                Q_EMIT importFileName(filename);
+                output.pop_back();
+            }
         }
     }
     return output;
@@ -382,11 +379,11 @@ SKGError SKGImportExportPlugin::importbackends()
             QString parameter;
 
             if (backend.contains(QStringLiteral("("))) {
-                QRegExp reg(QStringLiteral("^(.+)\\((.+)\\)$"));
-                int pos = reg.indexIn(backend);
-                if (pos != -1) {
-                    backend = reg.cap(1);
-                    parameter = reg.cap(2);
+                QRegularExpression reg(QStringLiteral("^(.+)\\((.+)\\)$"));
+                auto match = reg.match(backend);
+                if (match.hasMatch()) {
+                    backend = match.captured(1);
+                    parameter = match.captured(2);
                 } else {
                     err = SKGError(ERR_FAIL, i18nc("Error message", "Syntax error in backend \"%1\"", backend));
                     break;
