@@ -1,19 +1,8 @@
 
 /***************************************************************************
- *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
+ * SPDX-FileCopyrightText: 2021 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2021 G. DE BURE support@mankowski.fr
+ * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
  * This file is Skrooge plugin for operation management.
@@ -1083,8 +1072,8 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
         }, false);
     }
 
-    // Check operations not reconciliated
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgoperationplugin_notreconciliated"))) {
+    // Check operations not reconciled
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgoperationplugin_notreconciled"))) {
         nbConcurrentCheckTargeted++;
         m_currentBankDocument->concurrentExecuteSelectSqliteOrder(QStringLiteral("SELECT count(1), t_ACCOUNT FROM v_operation WHERE t_status='N' GROUP BY t_ACCOUNT HAVING count(1)>100 ORDER BY count(1) DESC"), [ & ](const SKGStringListList & iResult) {
             int nb = iResult.count();
@@ -1095,10 +1084,10 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
                 const QString& account = line.at(1);
 
                 SKGAdvice ad;
-                ad.setUUID("skgoperationplugin_notreconciliated|" % account);
+                ad.setUUID("skgoperationplugin_notreconciled|" % account);
                 ad.setPriority(9);
-                ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations of '%1' not reconciliated", account));
-                ad.setLongMessage(i18nc("Advice on making the best (long)", "Do not forget to reconciliate your accounts. By doing so, you acknowledge that your bank has indeed processed these operations on your account. This is how you enforce compliance with your bank's statements. See online help for more details"));
+                ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations of '%1' not reconciled", account));
+                ad.setLongMessage(i18nc("Advice on making the best (long)", "Do not forget to reconcile your accounts. By doing so, you acknowledge that your bank has indeed processed these operations on your account. This is how you enforce compliance with your bank's statements. See online help for more details"));
                 autoCorrections.resize(0);
                 {
                     SKGAdvice::SKGAdviceAction a;
@@ -1512,7 +1501,7 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
                                                "&operationWhereClause=" % SKGServices::encodeForUrl("t_number='" % SKGServices::stringToSqlString(num) % "' AND t_ACCOUNT='" % SKGServices::stringToSqlString(account) % '\''));
         return SKGError();
     }
-    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgoperationplugin_notreconciliated|"))) {
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgoperationplugin_notreconciled|"))) {
         // Get parameters
         QString account = iAdviceIdentifier.right(iAdviceIdentifier.length() - 36);
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/?currentPage=-1&modeInfoZone=1&account=" % SKGServices::encodeForUrl(account));
