@@ -1,18 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
+ * SPDX-FileCopyrightText: 2021 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2021 G. DE BURE support@mankowski.fr
+ * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
 * This file defines classes SKGImportExportManager.
@@ -26,7 +15,7 @@
 
 #include <qcryptographichash.h>
 #include <qfileinfo.h>
-#include <qregexp.h>
+#include <qregularexpression.h>
 #include <qtemporaryfile.h>
 #include <qtextcodec.h>
 
@@ -140,9 +129,9 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
             name.replace('_', ' ');
             name.replace('-', ' ');
             nameComplete = name;
-            QRegExp rx(QStringLiteral("(\\d{6,})"));
-            if (rx.indexIn(name) != -1) {
-                number = rx.cap(1);
+            auto match = QRegularExpression(QStringLiteral("(\\d{6,})")).match(name);
+            if (match.hasMatch()) {
+                number = match.captured(1);
                 if (name != number) {
                     name = name.remove(number).trimmed();
                 }
@@ -729,12 +718,12 @@ SKGError SKGImportExportManager::cleanBankImport()
 
                 // Comment is like this: <TYPE>  <INFO>
                 // Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
-                QRegExp rx(QStringLiteral("(.+) {2,}(.+)"));
                 QString comment = op.getComment();
-                if (rx.indexIn(comment) != -1) {
+                auto match = QRegularExpression(QStringLiteral("(.+) {2,}(.+)")).match(comment);
+                if (match.hasMatch()) {
                     // Get parameters
-                    QString mode = rx.cap(1);
-                    QString info = rx.cap(2);
+                    QString mode = match.captured(1);
+                    QString info = match.captured(2);
 
                     // Modify
                     err = op.setComment(info.trimmed());
@@ -755,12 +744,12 @@ SKGError SKGImportExportManager::cleanBankImport()
 
                 // Comment is like this: <TYPE> <INFO>
                 // Example: RETRAIT DAB 14-05-16607-482390
-                QRegExp rx(QStringLiteral("(\\S+) +(.+)"));
                 QString comment = op.getComment();
-                if (rx.indexIn(comment) != -1) {
+                auto match = QRegularExpression(QStringLiteral("(\\S+) +(.+)")).match(comment);
+                if (match.hasMatch()) {
                     // Get parameters
-                    QString mode = rx.cap(1);
-                    QString info = rx.cap(2);
+                    QString mode = match.captured(1);
+                    QString info = match.captured(2);
 
                     // Modify
                     err = op.setComment(info.trimmed());
@@ -781,11 +770,11 @@ SKGError SKGImportExportManager::cleanBankImport()
 
                 // Comment is like this: <TYPE>  <INFO>
                 // Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
-                QRegExp rx(QStringLiteral("(\\d+)"));
                 QString comment = op.getComment();
-                if (rx.indexIn(comment) != -1) {
+                auto match = QRegularExpression(QStringLiteral("(\\d+)")).match(comment);
+                if (match.hasMatch()) {
                     // Get parameters
-                    auto number = rx.cap(1);
+                    auto number = match.captured(1);
 
                     // Modify
                     err = op.setNumber(number);
