@@ -1,28 +1,10 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#**************************************************************************
-#*   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr
-#*   Redistribution and use in source and binary forms, with or without
-#*   modification, are permitted provided that the following conditions
-#*   are met:
-#*   
-#*   1. Redistributions of source code must retain the above copyright
-#*      notice, this list of conditions and the following disclaimer.
-#*   2. Redistributions in binary form must reproduce the above copyright
-#*      notice, this list of conditions and the following disclaimer in the
-#*      documentation and/or other materials provided with the distribution.
-#*   
-#*   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-#*   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-#*   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-#*   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-#*   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-#*   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-#*   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-#*   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-#*   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-#*   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#**************************************************************************
+#***************************************************************************
+#* SPDX-FileCopyrightText: 2021 S. MANKOWSKI stephane@mankowski.fr
+#* SPDX-FileCopyrightText: 2021 G. DE BURE support@mankowski.fr
+#* SPDX-License-Identifier: GPL-3.0-or-later
+#***************************************************************************
 
 """
 Created on Thu May 18 22:58:12 2017
@@ -65,8 +47,12 @@ def _get_cookie_crumb(ticker):
 	'''
 	# Perform a Yahoo financial lookup
 	url = 'https://finance.yahoo.com/quote/' + ticker
-	f = urllib.request.urlopen(url)
-	alines = f.read().decode('utf-8')
+	hdr = { 'User-Agent' : 'Mozilla/5.0 (Windows NT 6.1; Win64; x64)',
+		'content-type': 'text/html; charset=utf-8'}
+	req = urllib.request.Request(url, headers=hdr)
+	f = urllib.request.urlopen(req)
+	alines = f.read()
+	alines = alines.decode('utf-8')
 
 	# Extract the crumb from the response
 	global _crumb
