@@ -1,18 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
+ * SPDX-FileCopyrightText: 2021 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2021 G. DE BURE support@mankowski.fr
+ * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
  * This file is a generic Skrooge plugin for html reports.
@@ -29,6 +18,7 @@
 #include <qtemporaryfile.h>
 #include <qtoolbutton.h>
 #include <qwidgetaction.h>
+#include <qregularexpression.h>
 
 #include <klocalizedstring.h>
 #include <kcolorscheme.h>
@@ -300,7 +290,7 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
             QString stream;
             SKGError err = SKGReport::getReportFromTemplate(m_Report, m_Template, stream);
             IFKO(err) stream = err.getFullMessage();
-            stream = stream.remove(QRegExp(QStringLiteral("<img[^>]*/>")));
+            stream = stream.remove(QRegularExpression(QStringLiteral("<img[^>]*/>")));
 
             // Remove color of hyperlinks
             KColorScheme scheme(QPalette::Normal, KColorScheme::Window);
