@@ -1,24 +1,16 @@
 /***************************************************************************
- *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
+ * SPDX-FileCopyrightText: 2021 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2021 G. DE BURE support@mankowski.fr
+ * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
  * This file implements classes SKGDocument.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+
+#include "qregularexpression.h"
+
 #include "skgdocument.h"
 
 SKGError SKGDocument::refreshViewsIndexesAndTriggers(bool iForce) const
@@ -96,9 +88,9 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers(bool iForce) const
     IFOKDO(err, executeSqliteOrders(InitialDataModelTrigger))
     IFOK(err) {
         // Refresh dynamic triggers
-        QRegExp rx_rd(QStringLiteral("rd_([^_]+)_([^_]+).*"));
-        QRegExp rx_rc(QStringLiteral("rc_([^_]+)_([^_]+).*"));
-        QRegExp rx_r(QStringLiteral("r_([^_]+)_([^_]+).*"));
+        QRegularExpression rx_rd(QStringLiteral("rd_([^_]+)_([^_]+).*"));
+        QRegularExpression rx_rc(QStringLiteral("rc_([^_]+)_([^_]+).*"));
+        QRegularExpression rx_r(QStringLiteral("r_([^_]+)_([^_]+).*"));
         QStringList dbTables;
         err = this->getDistinctValues(QStringLiteral("sqlite_master"), QStringLiteral("name"), QStringLiteral("type='table'"), dbTables);
         int nb = dbTables.count();
@@ -108,30 +100,37 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers(bool iForce) const
             err = executeSelectSqliteOrder("PRAGMA table_info(" % table % ");", attributes);
             int nb2 = attributes.count();
             for (int j = 1; !err && j < nb2; ++j) {  // Header is ignored
-                QString att = attributes.at(j).at(1);
-                if (rx_rd.indexIn(att) != -1) {
+                auto att = attributes.at(j).at(1);
+                auto rx_rd_match = rx_rd.match(att);
+                if (rx_rd_match.hasMatch()) {
                     // Get parameters
-                    QString tab2 = rx_rd.cap(1);
-                    QString att2 = rx_rd.cap(2);
+                    QString tab2 = rx_rd_match.captured(1);
+                    QString att2 = rx_rd_match.captured(2);
                     QStringList sqlOrders;
                     sqlOrders << FOREIGNCONSTRAINTCASCADE(tab2, att2, table, att);
                     err = executeSqliteOrders(sqlOrders);
-                } else if (rx_rc.indexIn(att) != -1) {
-                    // Get parameters
-                    QString tab2 = rx_rc.cap(1);
-                    QString att2 = rx_rc.cap(2);
-                    QStringList sqlOrders;
-                    sqlOrders << FOREIGNCONSTRAINT(tab2, att2, table, att);
-                    err = executeSqliteOrders(sqlOrders);
-                } else if (rx_r.indexIn(att) != -1) {
-                    // Get parameters
-                    QString tab2 = rx_r.cap(1);
-                    QString att2 = rx_r.cap(2);
-                    QStringList sqlOrders;
-                    sqlOrders << FOREIGNCONSTRAINTUPDATE(tab2, att2, table, att);
-                    err = executeSqliteOrders(sqlOrders);
-                    // The following sql order error is not caught because this repair order is not mandatory
-                    executeSqliteOrder("UPDATE " % table % " SET " % att % "=0 WHERE " % att % "!=0 AND " % att % " NOT IN (SELECT DISTINCT(" % att2 % ") FROM " % tab2 % ')');
+                } else {
+                    auto rx_rc_match = rx_rc.match(att);
+                    if (rx_rc_match.hasMatch()) {
+                        // Get parameters
+                        QString tab2 = rx_rc_match.captured(1);
+                        QString att2 = rx_rc_match.captured(2);
+                        QStringList sqlOrders;
+                        sqlOrders << FOREIGNCONSTRAINT(tab2, att2, table, att);
+                        err = executeSqliteOrders(sqlOrders);
+                    } else {
+                        auto rx_r_match = rx_r.match(att);
+                        if (rx_r_match.hasMatch()) {
+                            // Get parameters
+                            QString tab2 = rx_r_match.captured(1);
+                            QString att2 = rx_r_match.captured(2);
+                            QStringList sqlOrders;
+                            sqlOrders << FOREIGNCONSTRAINTUPDATE(tab2, att2, table, att);
+                            err = executeSqliteOrders(sqlOrders);
+                            // The following sql order error is not caught because this repair order is not mandatory
+                            executeSqliteOrder("UPDATE " % table % " SET " % att % "=0 WHERE " % att % "!=0 AND " % att % " NOT IN (SELECT DISTINCT(" % att2 % ") FROM " % tab2 % ')');
+                        }
+                    }
                 }
             }
         }
